@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2012 Christoph L. Spiel
+ * Copyright (C) 2009-2015 Christoph L. Spiel
  *
  * This file is part of Enblend.
  *
@@ -37,7 +37,6 @@
 #include <cctype>
 
 #include <boost/algorithm/string/case_conv.hpp>
-#include <boost/assign/list_of.hpp>
 
 #include <vigra/imageinfo.hxx>
 
@@ -412,17 +411,12 @@ class Globbing
 public:
     Globbing() : algorithm_name_("literal"), algorithm_(NULL)
     {
-        installed_algorithms_ =
-            boost::assign::map_list_of
-            ("literal", MAKE_ALGORITHM(new LiteralGlobbingAlgorithm))
-            ("wildcard", MAKE_ALGORITHM(new WildcardGlobbingAlgorithm))
-#ifndef _WIN32
-            ("shell", MAKE_ALGORITHM(new ShellGlobbingAlgorithm))
-#endif
-            ;
-
+        installed_algorithms_["literal"] = MAKE_ALGORITHM(new LiteralGlobbingAlgorithm);
+        installed_algorithms_["wildcard"] = MAKE_ALGORITHM(new WildcardGlobbingAlgorithm);
         setup_alias("literal", "none");
+
 #ifndef _WIN32
+        installed_algorithms_["shell"] = MAKE_ALGORITHM(new ShellGlobbingAlgorithm);
         setup_alias("shell", "sh");
 #endif
     }
@@ -706,6 +700,7 @@ unfold_filename_iter(TraceableFileNameList& result, TraceInfo& trace_info, const
             trace_info.file_position.push_front(std::make_pair(response_filepath, line_number));
             ++trace_info.nesting_level;
             unfold_filename_iter(partial_result, trace_info, line);
+            --trace_info.nesting_level;
 
             for (TraceableFileNameList::const_iterator p = partial_result.begin();
                  p != partial_result.end();
